pub fn factorize_symbolic_cholesky<I: Index>(
A: SymbolicSparseColMatRef<'_, I>,
side: Side,
ord: SymmetricOrdering<'_, I>,
params: CholeskySymbolicParams<'_>,
) -> Result<SymbolicCholesky<I>, FaerError>Expand description
computes the symbolic cholesky factorization of the matrix $A$, or returns an error if the operation could not be completed